@@ -1,8 +1,6 @@
 use robotstxt_with_cache as robotstxt;
 
-#[allow(unused_imports)]
-use crate::_prelude::*;
-use crate::{types as rt, types::ExtError};
+use crate::{_prelude::*, types as rt, types::ExtError};
 
 #[derive(Clone, PartialEq, Debug, Copy)]
 pub enum Action {
